@@ -30,7 +30,7 @@ public:
     ~SddmKcm();
 
 public slots:
-    void save();
+    void save() Q_DECL_OVERRIDE;
 
 private:
     void prepareUi();
@@ -40,4 +40,4 @@ private:
     AdvanceConfig *mAdvanceConfig;
 };
 
-#endif // SDDMKCM_H
\ No newline at end of file
+#endif // SDDMKCM_H
