@@ -39,11 +39,15 @@ public:
 
 signals:
     void changed(bool);
+    void themesChanged();
     
 private slots:
     void themeSelected(const QModelIndex &index);
     void backgroundChanged(const QString &imagePath);
-    
+    void getNewStuffClicked();
+    void installFromFileClicked();
+    void removeThemeClicked();
+
 private:
     Ui::ThemeConfig *configUi;
     KSharedConfigPtr mConfig;
@@ -56,4 +60,4 @@ private:
     void dump();
 };
 
-#endif // THEMECONFIG_H
\ No newline at end of file
+#endif // THEMECONFIG_H
